==> dsh-bio-1.3.1-0.tar.bz2: share/dsh-bio-1.3.1-0/conda_build.sh <==
if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/conda/conda-bld/dsh-bio_1579019541136/work/build_env_setup.sh
fi
#!/bin/bash

BINARY_HOME=$PREFIX/bin
PACKAGE_HOME=$PREFIX/share/$PKG_NAME-$PKG_VERSION-$PKG_BUILDNUM

mkdir -p $BINARY_HOME
mkdir -p $PACKAGE_HOME

cp -R * $PACKAGE_HOME

ln -s $PACKAGE_HOME/bin/dsh-bio $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gfa1 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gfa2 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gff3 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-sam $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-create-sequence-dictionary $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-disinterleave-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-downsample-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-downsample-interleaved-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-extract-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-extract-fastq-by-length $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fasta-to-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fastq-description $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fastq-sequence-length $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fastq-to-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gfa1 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gfa2 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gff3 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-sam $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-gfa1-to-gfa2 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-interleave-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-intersect-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-remap-phase-set $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-rename-references $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-gff3 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-interleaved-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-sam $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-traverse-paths $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-truncate-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-variant-table-to-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-vcf-header $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-vcf-pedigree $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-vcf-samples $BINARY_HOME

==> dsh-bio-2.0.2-0.tar.bz2: share/dsh-bio-2.0.2-0/conda_build.sh <==
if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/conda/conda-bld/dsh-bio_1613664200466/work/build_env_setup.sh
fi
#!/bin/bash

BINARY_HOME=$PREFIX/bin
PACKAGE_HOME=$PREFIX/share/$PKG_NAME-$PKG_VERSION-$PKG_BUILDNUM

mkdir -p $BINARY_HOME
mkdir -p $PACKAGE_HOME

cp -R * $PACKAGE_HOME

ln -s $PACKAGE_HOME/bin/dsh-bio $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gaf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gfa1 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gfa2 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-gff3 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-sam $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-paf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-compress-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-create-sequence-dictionary $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-disinterleave-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-downsample-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-downsample-interleaved-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-extract-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-extract-fastq-by-length $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fasta-to-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fastq-description $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fastq-sequence-length $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-fastq-to-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gaf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gfa1 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gfa2 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-gff3 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-paf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-sam $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-filter-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-gfa1-to-gfa2 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-interleave-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-intersect-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-remap-dbsnp $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-remap-phase-set $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-rename-bed-references $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-rename-gff3-references $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-rename-vcf-references $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-bed $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-gaf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-gff3 $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-interleaved-fastq $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-paf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-sam $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-split-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-traverse-paths $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-truncate-fasta $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-variant-table-to-vcf $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-vcf-header $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-vcf-pedigree $BINARY_HOME
ln -s $PACKAGE_HOME/bin/dsh-vcf-samples $BINARY_HOME
